==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/GetVirtualMachinePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.GetVirtualMachinePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The Resource Group Name.
 * @property virtualMachineName Name of the virtual machine resource.
 */
public data class GetVirtualMachinePlainArgs(
    public val resourceGroupName: String,
    public val virtualMachineName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.GetVirtualMachinePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.GetVirtualMachinePlainArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.GetVirtualMachinePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .virtualMachineName(virtualMachineName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualMachinePlainArgs].
 */
@PulumiTagMarker
public class GetVirtualMachinePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var virtualMachineName: String? = null

    /**
     * @param value The Resource Group Name.
     */
    @JvmName("dfusweohfdudsqig")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the virtual machine resource.
     */
    @JvmName("fxmtecvvnpwsenaw")
    public suspend fun virtualMachineName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.virtualMachineName = mapped
    }

    internal fun build(): GetVirtualMachinePlainArgs = GetVirtualMachinePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        virtualMachineName = virtualMachineName ?: throw PulumiNullFieldException("virtualMachineName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/GetVirtualMachinePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.GetVirtualMachinePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The Resource Group Name.
 * @property virtualMachineName Name of the virtual machine resource.
 */
public data class GetVirtualMachinePlainArgs(
    public val resourceGroupName: String,
    public val virtualMachineName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.GetVirtualMachinePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.GetVirtualMachinePlainArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.GetVirtualMachinePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .virtualMachineName(virtualMachineName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualMachinePlainArgs].
 */
@PulumiTagMarker
public class GetVirtualMachinePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var virtualMachineName: String? = null

    /**
     * @param value The Resource Group Name.
     */
    @JvmName("lifvtcqbhdemfxri")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of the virtual machine resource.
     */
    @JvmName("xspkrfxtgokgdpkn")
    public suspend fun virtualMachineName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.virtualMachineName = mapped
    }

    internal fun build(): GetVirtualMachinePlainArgs = GetVirtualMachinePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        virtualMachineName = virtualMachineName ?: throw PulumiNullFieldException("virtualMachineName"),
    )
}
